Crate embedded_huffman

Structs

Enums

  • Decompression errors can be malformed data or the error from the FutureFn

Traits

Type Aliases

  • A function that takes a mutable reference to the page and fills it with bytes from NAND The future returns true if there are more pages that could be read
  • A function that takes a reference to the page and writes it to NAND