pub struct Encoder { /* private fields */ }Expand description
A huffman encoder that writes successive tables and data to pages
Implementations
Sourceimpl Encoder
impl Encoder
Sourcepub fn new(page_size: usize, page_threshold: usize) -> Encoder
pub fn new(page_size: usize, page_threshold: usize) -> Encoder
Create an encoder that writes into pages of page_size bytes
and rebuilds the frequency table every page_threshold pages.
Sourcepub fn reset(&mut self)
pub fn reset(&mut self)
Prepare the encoder for a new round of encoding this keeps allocations, so its cheaper than a Encoder::new call
Sourcepub async fn sink<E>(
&mut self,
byte: u8,
output: &mut impl PageWriter<E>,
) -> Result<bool, E>
pub async fn sink<E>( &mut self, byte: u8, output: &mut impl PageWriter<E>, ) -> Result<bool, E>
Put a byte into the encoder
Sourcepub async fn flush<E>(
&mut self,
output: &mut impl PageWriter<E>,
) -> Result<bool, E>
pub async fn flush<E>( &mut self, output: &mut impl PageWriter<E>, ) -> Result<bool, E>
Finish encoding and flush any remaining bytes