Structs
- A huffman decoder that reads successive tables and data from pages
- A huffman encoder that writes successive tables and data to pages
Enums
- Decompression errors can be malformed data or the error from the FutureFn
Traits
- A reader that reads pages from NAND
Type Aliases
- A function that takes a mutable reference to the page and fills it with bytes from NAND The future returns true if there are more pages that could be read
- A function that takes a reference to the page and writes it to NAND